//
//  CalendarView.swift
//  OnLeash_Alpha50
//
//  Created by Jessica Sherrington on 11/18/23.
//

import SwiftUI

enum ScheduleCategory: String, CaseIterable {
    case meals
    case walks
    case potty
    case vetVisits = "vet visits"
    case medication
    case grooming
    case misc
}
struct CustomColor {
    static let myColor = Color("OnLeashPink")
}

struct CalendarView: View {
        @State private var selectedDate = Date()
        @State private var scheduleItems: [ScheduleItem] = []
        @State private var isAddItemSheetPresented = false
        @State private var newItemTitle = ""
        @State private var newItemTime = ""
        @State private var selectedCategory: ScheduleCategory = .meals
        @State private var isRecurring = false
        @State private var hasReminder = false

    var body: some View {
            NavigationView {
                ScrollView {
                VStack {
                    DatePicker("Select a Date", selection: $selectedDate, in: Date()..., displayedComponents: .date)
                        .datePickerStyle(GraphicalDatePickerStyle())
                        .padding()
                    
                    List {
                        ForEach(scheduleItems) { item in
                            ScheduleRow(scheduleItem: item)
                        }
                        .onDelete(perform: deleteItems)
                        .accentColor(CustomColor.myColor)
                        
                    }
                    
                    Button("Add Schedule Item") {
                        isAddItemSheetPresented.toggle()
                    }
                    .padding()
                    .sheet(isPresented: $isAddItemSheetPresented) {
                        AddItemSheet(
                            isPresented: $isAddItemSheetPresented,
                            newItemTitle: $newItemTitle,
                            newItemTime: $newItemTime,
                            selectedCategory: $selectedCategory,
                            isRecurring: $isRecurring,
                            hasReminder: $hasReminder,
                            onAdd: {
                                let newItem = ScheduleItem(
                                    title: newItemTitle,
                                    time: newItemTime,
                                    category: selectedCategory,
                                    isRecurring: isRecurring,
                                    hasReminder: hasReminder
                                )
                                scheduleItems.append(newItem)
                            }
                        )
                    }

                }
                .tint(CustomColor.myColor)
                
            }
        }
        
    }

    private func deleteItems(at offsets: IndexSet) {
        scheduleItems.remove(atOffsets: offsets)
    }
}

struct ScheduleRow: View {
    var scheduleItem: ScheduleItem

    var body: some View {
        HStack {
            Text(scheduleItem.title)
            Spacer()
            Text(scheduleItem.time)
        }
        .tint(CustomColor.myColor)
    }
}

struct AddItemSheet: View {
    @Binding var isPresented: Bool
    @Binding var newItemTitle: String
    @Binding var newItemTime: String
    @Binding var selectedCategory: ScheduleCategory
    @Binding var isRecurring: Bool
    @Binding var hasReminder: Bool
    var onAdd: () -> Void

    var body: some View {
        NavigationView {
            Form {
                Section(header: Text("New Schedule Item")) {
                    TextField("Title", text: $newItemTitle)
                    TextField("Time", text: $newItemTime)
                }

                Section {
                    Picker("Category", selection: $selectedCategory) {
                        ForEach(ScheduleCategory.allCases, id: \.self) { category in
                            Text(category.rawValue.capitalized)
                        }
                    }

                    Toggle("Recurring", isOn: $isRecurring)
                    Toggle("Set Reminder", isOn: $hasReminder)

                    Button("Add") {
                        onAdd()
                        isPresented = false
                    }
                }
                .tint(CustomColor.myColor)

            }
            .navigationTitle("Add Schedule Item")
            .navigationBarItems(trailing: Button("Cancel") {
                isPresented = false
            })
        }
        .tint(CustomColor.myColor)
    }
}


struct ScheduleItem: Identifiable {
    var id = UUID()
      var title: String
      var time: String
      var category: ScheduleCategory
      var isRecurring: Bool
      var hasReminder: Bool
}


struct CalendarView_Previews: PreviewProvider {
    static var previews: some View {
        CalendarView()
    }
}


